---
label: KILOSORT
dockerfile:
environment: MATLAB
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/kilosort/kilosort.py
website: https://github.com/cortex-lab/KiloSort
source_code: https://github.com/cortex-lab/KiloSort
authors: Marius Pachitariu
processor_name: KiloSort
doi: 10.1101/061481
---
_
# KILOSORT

## Description

*From the KiloSort website*: Fast spike sorting for hundreds of channels. Implements an integrated template matching framework for detecting and clustering spikes from multi-channel electrophysiological recordings.

## References

[1] Pachitariu, Marius, et al. "Fast and accurate spike sorting of high-channel count probes with KiloSort." Advances in Neural Information Processing Systems. 2016.

[2] Pachitariu, Marius, et al. "Kilosort: realtime spike-sorting for extracellular electrophysiology with hundreds of channels." BioRxiv (2016): 061481.